@@ -25,7 +25,7 @@ def show_clsf_stats(y, c, cls, c_szs, c_dist):
         pd.DataFrame(c_dist,columns=['dist'])
     ], axis=1)
     print(f'\nClassification dataset: {frmt_n(len(y))} records, {frmt_n(c)} classes')
-    if len(y.shape)>1: print(f'Total number of labels {[frmt_n(e) for e in y.shape]} -> {frmt_n(np.asarray(c_szs).sum())}')
+    if len(y.shape)>1: print(f'Total number of labels {y.shape} -> {np.asarray(c_szs).sum():,}')
     display(df)
 
 def prep_cls(y, cls_to_idx=None, cls=None):
